@@ -15,7 +15,12 @@
  */
 
 //! Common definitions for components of Decision Model and Notation Toolkit.
-//!
+
+extern crate serde;
+extern crate serde_derive;
+extern crate serde_yaml;
+extern crate uriparse;
+
 mod config;
 mod constants;
 mod errors;
